# MRKDWN 2 HTML

Converting between Markdown and HTML.

Still under development. Avaliable on pip, to install:

`pip install mrkdwn2html`

The primary function is mrkdwn2html(mrkdwn) which returns the converted string.
